<div class="card">
    <h5 class="card-header"><span class="text-muted">Unknown OS</span></h5>
    <div class="card-footer text-end noprint">
        <a href="{% url 'plugins:netbox_storage:volume_add' %}" class="btn btn-sm btn-primary">
            <span class="mdi mdi-plus-thick" aria-hidden="true"></span> Add Volume
        </a>
    </div>


</div>